@@ -25,7 +25,7 @@
 //arbitrary number for ftok function
 #define SHM_projectID 23
 
-Genome::Genome (Parameters &Pin ): pGe(Pin.pGe), P(Pin), shmStart(NULL), sharedMemory(NULL) {
+Genome::Genome (Parameters &Pin ): pGe(Pin.pGe), sharedMemory(NULL), P(Pin), shmStart(NULL) {
     shmKey=ftok(pGe.gDir.c_str(),SHM_projectID);    
     
     sjdbOverhang = pGe.sjdbOverhang; //will be re-defined later if another value was used for the generated genome
@@ -55,20 +55,25 @@ uint Genome::OpenStream(string name, ifstream & stream, uint size)
     stream.open((pGe.gDir+ "/" +name).c_str(), ios::binary);
     if (!stream.good()) {
         ostringstream errOut;
-        errOut << "EXITING because of FATAL ERROR: could not open genome file "<< pGe.gDir << "/" << name <<"\n" << endl;
+        errOut << "EXITING because of FATAL ERROR: could not open genome file: "<< pGe.gDir << "/" << name <<"\n";
         errOut << "SOLUTION: check that the path to genome files, specified in --genomeDir is correct and the files are present, and have user read permissions\n" <<flush;
         exitWithError(errOut.str(),std::cerr, P.inOut->logMain, EXIT_CODE_GENOME_FILES, P);
     };
 
 
-    if (size>0)
-    {
+    if (size>0) {
         P.inOut->logMain << name << ": size given as a parameter = " << size <<"\n";
-    } else
-    {
+    } else {
         P.inOut->logMain << "Checking " << name << " size";
         stream.seekg (0, ios::end);
-        size=(uint) stream.tellg();
+        int64 size1 = stream.tellg();
+        if (size1<=0) {
+            ostringstream errOut;
+            errOut << "EXITING because of FATAL ERROR: failed reading from genome file: "<< pGe.gDir << "/" << name <<"\n";
+            errOut << "SOLUTION: re-generate the genome index\n";
+            exitWithError(errOut.str(),std::cerr, P.inOut->logMain, 1, P);
+        };
+        size=(uint) size1;
         stream.clear();
         stream.seekg (0, ios::beg);
         P.inOut->logMain << "file size: "<< size <<" bytes; state: good=" <<stream.good()\
@@ -240,106 +245,80 @@ void Genome::genomeLoad(){//allocate and load Genome
 
     shmSize=SA.lengthByte + nGenome+L+L+SHM_startG+8;
     shmSize+= SAi.lengthByte;
-    if (P.annotScoreScale>0) shmSize+=nGenome;
-
 
     if ((pGe.gLoad=="LoadAndKeep" ||
          pGe.gLoad=="LoadAndRemove" ||
          pGe.gLoad=="LoadAndExit" ||
-         pGe.gLoad=="Remove") && sharedMemory == NULL)
-    {
+         pGe.gLoad=="Remove") && sharedMemory == NULL) {
+        
         bool unloadLast = pGe.gLoad=="LoadAndRemove";
-        try
-        {
+        try {
             sharedMemory = new SharedMemory(shmKey, unloadLast);
             sharedMemory->SetErrorStream(P.inOut->logStdOut);
 
             if (!sharedMemory->NeedsAllocation())
             P.inOut->logMain <<"Found genome in shared memory\n"<<flush;
 
-    if (pGe.gLoad=="Remove") {//kill the genome and exit
+            if (pGe.gLoad=="Remove") {//kill the genome and exit
                 if (sharedMemory->NeedsAllocation()) {//did not find genome in shared memory, nothing to kill
-            ostringstream errOut;
-            errOut << "EXITING: Did not find the genome in memory, did not remove any genomes from shared memory\n";
-            exitWithError(errOut.str(),std::cerr, P.inOut->logMain, EXIT_CODE_GENOME_FILES, P);
-        } else {
-                    sharedMemory->Clean();
-            P.inOut->logMain <<"DONE: removed the genome from shared memory\n"<<flush;
-                    return;
-        };
-            }
+                ostringstream errOut;
+                errOut << "EXITING: Did not find the genome in memory, did not remove any genomes from shared memory\n";
+                exitWithError(errOut.str(),std::cerr, P.inOut->logMain, EXIT_CODE_GENOME_FILES, P);
+                } else {
+                            sharedMemory->Clean();
+                    P.inOut->logMain <<"DONE: removed the genome from shared memory\n"<<flush;
+                            return;
+                };
+            };
 
             if (sharedMemory->NeedsAllocation()){
                 P.inOut->logMain <<"Allocating shared memory for genome\n"<<flush;
                 sharedMemory->Allocate(shmSize);
-            }
-        }
-        catch (const SharedMemoryException & exc)
-        {
+            };
+        } catch (const SharedMemoryException & exc){
             HandleSharedMemoryException(exc, shmSize);
-        }
+        };
 
         shmStart = (char*) sharedMemory->GetMapped();
         shmNG= (uint*) (shmStart+SHM_sizeG);
         shmNSA= (uint*) (shmStart+SHM_sizeSA);
 
-        if (!sharedMemory->IsAllocator())
-        {
+        if (!sharedMemory->IsAllocator()) {
             // genome is in shared memory or being loaded
             // wait for the process that will populate it
             // and record the sizes
-
-        uint iwait=0;
+            uint iwait=0;
             while (*shmNG != nGenome) {
-            iwait++;
-            P.inOut->logMain <<"Another job is still loading the genome, sleeping for 1 min\n" <<flush;
-            sleep(60);
-            if (iwait==100) {
-                ostringstream errOut;
-                errOut << "EXITING because of FATAL ERROR: waited too long for the other job to finish loading the genome" << strerror(errno) << "\n" <<flush;
+                iwait++;
+                P.inOut->logMain <<"Another job is still loading the genome, sleeping for 1 min\n" <<flush;
+                sleep(60);
+                if (iwait==100) {
+                    ostringstream errOut;
+                    errOut << "EXITING because of FATAL ERROR: waited too long for the other job to finish loading the genome" << strerror(errno) << "\n" <<flush;
                     errOut << "SOLUTION: remove the shared memory chunk by running STAR with --genomeLoad Remove, and restart STAR" <<flush;
                     exitWithError(errOut.str(),std::cerr, P.inOut->logMain, EXIT_CODE_GENOME_LOADING_WAITED_TOO_LONG, P);
+                };
             };
-        };
-
-            if (nSAbyte!=*shmNSA)
-            {
+            if (nSAbyte!=*shmNSA){
                 ostringstream errOut;
                 errOut << "EXITING because of FATAL ERROR: the SA file size did not match what we found in shared memory" << "\n" << flush;
                 errOut << "SOLUTION: remove the shared memory chunk by running STAR with --genomeLoad Remove, and restart STAR" << flush;
                 exitWithError(errOut.str(),std::cerr, P.inOut->logMain, EXIT_CODE_INCONSISTENT_DATA, P);
-            }
-
+            };
             P.inOut->logMain << "Using shared memory for genome. key=0x" <<hex<<shmKey<<dec<< ";   shmid="<< sharedMemory->GetId() <<endl<<flush;
-        }
-
+        };
         G1=shmStart+SHM_startG;
         SA.pointArray(G1+nGenome+L+L);
         char* shmNext=SA.charArray+nSAbyte;
 
         SAi.pointArray(shmNext);
         shmNext += SAi.lengthByte;
-
-//     if (twoPass.pass1readsN==0) {//not 2-pass
-//         shmStartG=SHM_startSHM;
-//         shmStartSA=0;
-//     } else {//2-pass
-//         ostringstream errOut;
-//         errOut << "EXITING because of FATAL ERROR: 2-pass procedure cannot be used with genome already loaded im memory'  "\n" ;
-//         errOut << "SOLUTION: check shared memory settigns as explained in STAR manual, OR run STAR with --genomeLoad NoSharedMemory to avoid using shared memory\n" <<flush;
-//         exitWithError(errOut.str(),std::cerr, P.inOut->logMain, EXIT_CODE_SHM, P);
-//     };
-     if (P.annotScoreScale>0) {//optional allocation
-            shmNext += nGenome;
-        }
-    }
-    else if (pGe.gLoad=="NoSharedMemory") // simply allocate memory, do not use shared memory
-    {
+    } else if (pGe.gLoad=="NoSharedMemory") {// simply allocate memory, do not use shared memory
         genomeInsertL=0;
+        genomeInsertChrIndFirst=nChrReal;
         if (pGe.gFastaFiles.at(0)!="-")
         {//will insert sequences in the genome, now estimate the extra size
            uint oldlen=chrStart.back();//record the old length
-           genomeInsertChrIndFirst=nChrReal;
            genomeInsertL=genomeScanFastaFiles(P, G, false, *this)-oldlen;
         };
 
@@ -547,7 +526,7 @@ void Genome::genomeLoad(){//allocate and load Genome
         P.winBinNbits = (uint) floor( log2( max( max(4LLU,P.alignIntronMax), (P.alignMatesGapMax==0 ? 1000LLU : P.alignMatesGapMax) ) /4 ) + 0.5);
         P.winBinNbits = max( P.winBinNbits, (uint) floor(log2(nGenome/40000+1)+0.5) ); 
         //ISSUE - to be fixed in STAR3: if alignIntronMax>0 but alignMatesGapMax==0, winBinNbits will be defined by alignIntronMax
-        P.inOut->logMain << "To accomodate alignIntronMax="<<P.alignIntronMax<<" redefined winBinNbits="<< P.winBinNbits <<endl;
+        P.inOut->logMain << "To accommodate alignIntronMax="<<P.alignIntronMax<<" redefined winBinNbits="<< P.winBinNbits <<endl;
 
     };
 
