@@ -23,12 +23,13 @@ InOutStreams::~InOutStreams() {
     logFinal.flush();
     outLocalChains.flush();
 
-    logStdOutFile.close();
+    //logStdOutFile.close(); //do not want to close these log files, as some destructors (e.g. ~SharedMemory) might still write there
+    //logMain.close();
+    
     outSAMfile.close();
     outChimSAM.close();
     outChimJunction.close();
     logProgress.close();
-    logMain.close();
     logFinal.close();
     outLocalChains.close();
 
