@@ -1,5 +1,5 @@
-#ifndef READ_ALIGN_CHUNK_DEF
-#define READ_ALIGN_CHUNK_DEF
+#ifndef CODE_ReadAlignChunk
+#define CODE_ReadAlignChunk
 
 #include "IncludeDefine.h"
 #include "Parameters.h"
@@ -11,7 +11,7 @@
 
 class ReadAlignChunk {//chunk of reads and alignments
 public:
-    Parameters* P;
+    Parameters& P;
     ReadAlign* RA;
 
     Transcriptome *chunkTr;
@@ -32,13 +32,16 @@ public:
     uint iChunkIn; //current chunk # as read from .fastq
     uint iChunkOutSAM; //current chunk # writtedn to Aligned.out.sam
     int iThread; //current thread
-    uint chunkOutBAMtotal, chunkOutBAMtotal1; //total number of bytes in the write buffer
+    uint chunkOutBAMtotal; //total number of bytes in the write buffer
 
-    ReadAlignChunk(Parameters* Pin, Genome &genomeIn, Transcriptome *TrIn, int iChunk);
+    ReadAlignChunk(Parameters& Pin, Genome &genomeIn, Transcriptome *TrIn, int iChunk);
     void processChunks();
     void mapChunk();
     void chunkFstreamOpen(string filePrefix, int iChunk, fstream &fstreamOut);
     void chunkFstreamCat (fstream &chunkOut, ofstream &allOut, bool mutexFlag, pthread_mutex_t &mutexVal);
     void chunkFilesCat(ostream *allOut, string filePrefix, uint &iC);
+    
+    Genome &mapGen;    
+private:
 };
 #endif
