@@ -139,7 +139,7 @@ void convertNucleotidesToNumbers(const char* R0, char* R1, const uint Lread) {//
                         case (84): case(116): 
                             R1[jj]=char(3);break;//T
                         default:                              
-                            R1[jj]=char(9);//anything else
+                            R1[jj]=char(4);//anything else is converted to N
                     };
                 };
 };
@@ -160,7 +160,7 @@ uint convertNucleotidesToNumbersRemoveControls(const char* R0, char* R1, const u
                 if (int(R0[jj]) < 32) {//control characters are skipped
                     continue;
                 } else {//all non-control non-ACGT characters are convreted to N
-                    R1[jj]=char(9);//anything else
+                    R1[jj]=char(4);//anything else
                 };
         };
         ++iR1;
@@ -193,6 +193,36 @@ char convertNt01234(const char R0) {//transform sequence  from ACGT into 0-1-2-3
     };
 };
 
+int32 convertNuclStrToInt32(const string S, uint32 &intOut) {
+    intOut=0;
+    int32 posN=-1;
+    for (uint32 ii=0; ii<S.size(); ii++) {
+        uint32 nt = (uint32) convertNt01234(S.at(ii));
+        if (nt>3) {//N
+            if (posN>=0)
+                return -2; //two Ns
+            posN=ii;
+            nt=0;
+        };
+        intOut = intOut << 2;
+        intOut +=nt;
+        //intOut += nt<<(2*ii);
+    };
+    return posN;
+};
+
+string convertNuclInt32toString(uint32 nuclNum, const uint32 L) {
+    string nuclOut(L,'N');
+    string nuclChar="ACGT";
+
+    for (uint32 ii=1; ii<=L; ii++) {
+        nuclOut[L-ii] = nuclChar[nuclNum & 3];
+        nuclNum = nuclNum >> 2;
+    };
+    return nuclOut;
+};
+
+
 uint chrFind(uint Start, uint i2, uint* chrStart) {// find chromosome from global locus
     uint i1=0, i3;
     while (i1+1<i2) {
