@@ -1,9 +1,4 @@
 /**  general basic functions to operate on sequences, no classes
- *
- *
- * A longer description.
- *
- * @see something
  */
 
 #ifndef SEQUENCEFUNS_DEF
@@ -26,4 +21,7 @@ uint localSearchNisMM(const char *x, uint nx, const char *y, uint ny, double pMM
 
 uint qualitySplit(char*, char*, uint, char, uint, uint, uint**);
 
+int32 convertNuclStrToInt32(const string S, uint32 &intOut);
+string convertNuclInt32toString(const uint32 nuclNum, const uint32 L);
+
 #endif
